Retrieves cash flow statement data from Yahoo Finance for multiple specified ticker symbols. Cash flow statements show how changes in balance sheet accounts and income affect cash and cash equivalents, breaking the analysis down to operating, investing, and financing activities.
Arguments
- tickers_obj
A tickers object created with get_tickers()
- freq
Frequency of data: "annual" or "quarterly" (default "annual")
- start
Start timestamp as date, datetime, or string (default EOY 2016)
- end
End timestamp as date, datetime, or string (default current timestamp)
- cashflow_keys
Vector of specific cash flow statement keys to include (default all) See
valid_cashflow_keysfor available options.- pretty
Format column names to be more readable (default TRUE)
- wide
Return data in wide format with dates as columns (default TRUE). If FALSE, returns data in long format with a date column.
- proxy
Optional proxy settings for the request
- output
Object to return. Can be "tibble", "response", or "request" (default "tibble")
Examples
if (FALSE) { # \dontrun{
tech_tickers <- get_tickers(c("AAPL", "MSFT", "GOOG"))
tech_cashflow <- get_tickers_cashflow(tech_tickers)
} # }