Get all financial statements for multiple tickers
Arguments
- tickers_obj
A tickers object created with get_tickers()
- freq
Frequency of data: "annual" or "quarterly" (default "annual")
- start
Start timestamp as date, datetime, or string (default EOY 2016)
- end
End timestamp as date, datetime, or string (default current timestamp)
- cashflow_keys
Vector of specific cash flow statement keys to include (default all) See
valid_cashflow_keysfor available options.- balance_keys
Vector of specific balance sheet keys to include (default all) See
valid_balance_keysfor available options.- income_keys
Vector of specific income statement keys to include (default all) See
valid_income_keysfor available options.- pretty
Format column names to be more readable (default TRUE)
- wide
Return data in wide format with dates as columns (default TRUE). If FALSE, returns data in long format with a date column.
- proxy
Optional proxy settings for the request
- output
Object to return. Can be "tibble", "response", or "request" (default "tibble")
Examples
if (FALSE) { # \dontrun{
tech_tickers <- get_tickers(c("AAPL", "MSFT", "GOOG"))
tech_financials <- get_tickers_financials(tech_tickers)
} # }