Skip to contents

A dataset containing the possible modules that can be requested from the Yahoo Finance API. Each module represents a specific type of financial data that can be retrieved for a ticker.

Usage

valid_modules

Format

A character vector containing 33 possible API modules with descriptions

Yahoo Finance API

Details

The modules include:

  • assetProfile - Summary profile and company officers

  • balanceSheetHistory - Annual balance sheet data

  • balanceSheetHistoryQuarterly - Quarterly balance sheet data

  • calendarEvents - Future earnings dates

  • cashFlowStatementHistory - Annual cash flow statement data

  • cashFlowStatementHistoryQuarterly - Quarterly cash flow statement data

  • defaultKeyStatistics - Key performance indicators (PE, enterprise value, EPS, etc.)

  • earnings - Earnings history

  • earningsHistory - Historical earnings data

  • earningsTrend - Earnings trend data

  • esgScores - Environmental, social, and governance scores

  • financialData - Financial KPIs (revenue, margins, cash flow, etc.)

  • institutionOwnership - Institutional ownership data

  • insiderHolders - Insider holdings data

  • insiderTransactions - Insider transaction data

  • and more...

Examples

# View all possible modules
data(valid_modules)
head(valid_modules)
#> [1] "assetProfile"                      "balanceSheetHistory"              
#> [3] "balanceSheetHistoryQuarterly"      "calendarEvents"                   
#> [5] "cashFlowStatementHistory"          "cashFlowStatementHistoryQuarterly"

# Check if a specific module exists
"financialData" %in% valid_modules
#> [1] TRUE